==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/APIKEYID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for APIKEYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="APIKEYID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}USERID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}INTEGRATIONAPPLICATIONID"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "APIKEYID_Type", propOrder = {
    "userid",
    "integrationapplicationid"
})
public class APIKEYID_Type {

    @XmlElement(name = "USERID", required = true)
    protected USERID_Type userid;
    @XmlElement(name = "INTEGRATIONAPPLICATIONID", required = true)
    protected USERDEFINEDCODEID_Type integrationapplicationid;

    /**
     * Gets the value of the userid property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUSERID() {
        return userid;
    }

    /**
     * Sets the value of the userid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUSERID(USERID_Type value) {
        this.userid = value;
    }

    /**
     * Gets the value of the integrationapplicationid property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getINTEGRATIONAPPLICATIONID() {
        return integrationapplicationid;
    }

    /**
     * Sets the value of the integrationapplicationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setINTEGRATIONAPPLICATIONID(USERDEFINEDCODEID_Type value) {
        this.integrationapplicationid = value;
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_fields/APIKEYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for APIKEYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="APIKEYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INTEGRATIONAPPLICATIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "APIKEYID_Type", propOrder = {
    "userid",
    "integrationapplicationid"
})
public class APIKEYID_Type {

    @XmlElement(name = "USERID", required = true)
    protected USERID_Type userid;
    @XmlElement(name = "INTEGRATIONAPPLICATIONID", required = true)
    protected USERDEFINEDCODEID_Type integrationapplicationid;

    /**
     * Gets the value of the userid property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUSERID() {
        return userid;
    }

    /**
     * Sets the value of the userid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUSERID(USERID_Type value) {
        this.userid = value;
    }

    /**
     * Gets the value of the integrationapplicationid property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getINTEGRATIONAPPLICATIONID() {
        return integrationapplicationid;
    }

    /**
     * Sets the value of the integrationapplicationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setINTEGRATIONAPPLICATIONID(USERDEFINEDCODEID_Type value) {
        this.integrationapplicationid = value;
    }

}
